@@ -12,7 +12,7 @@ class DeepL(object):
     """
     _languages = DEEPL_LANGUAGE_TO_CODE
 
-    def __init__(self, api_key=None, source="en", target="en", use_free_api=True):
+    def __init__(self, api_key=None, source="en", target="en", use_free_api=True, **kwargs):
         """
         @param api_key: your DeepL api key.
         Get one here: https://www.deepl.com/docs-api/accessing-the-api/
@@ -30,7 +30,7 @@ class DeepL(object):
         else:
             self.__base_url = BASE_URLS.get("DEEPL").format(version=self.version)
 
-    def translate(self, text):
+    def translate(self, text, **kwargs):
         """
         @param text: text to translate
         @return: translated text
@@ -60,18 +60,18 @@ class DeepL(object):
         # Process and return the response.
         return res['translations'][0]['text']
 
-    def translate_batch(self, batch):
+    def translate_batch(self, batch, **kwargs):
         """
         @param batch: list of texts to translate
         @return: list of translations
         """
-        return [self.translate(text) for text in batch]
+        return [self.translate(text, **kwargs) for text in batch]
 
-    def _is_language_supported(self, lang):
+    def _is_language_supported(self, lang, **kwargs):
         # The language is supported when is in the dicionary.
         return lang == 'auto' or lang in self._languages.keys() or lang in self._languages.values()
 
-    def _map_language_to_code(self, lang):
+    def _map_language_to_code(self, lang, **kwargs):
         if lang in self._languages.keys():
             return self._languages[lang]
         elif lang in self._languages.values():
