@@ -6,7 +6,7 @@ from deep_translator.configs import config
 from requests.exceptions import HTTPError
 
 
-def get_request_body(text, api_key, *args):
+def get_request_body(text, api_key, *args, **kwargs):
     """
     send a request and return the response body parsed as dictionary
 
@@ -58,7 +58,7 @@ def single_detection(text, api_key=None, detailed=False, *args, **kwargs):
         return lang
 
 
-def batch_detection(text_list, api_key, detailed=False, *args):
+def batch_detection(text_list, api_key, detailed=False, *args, **kwargs):
     """
     function responsible for detecting the language from a text
 
