@@ -2,7 +2,6 @@
 Yandex translator API
 """
 import requests
-from requests import exceptions
 from deep_translator.constants import BASE_URLS
 from deep_translator.exceptions import (RequestError,
                                         ServerException, TranslationNotFound, TooManyRequests)
@@ -13,13 +12,15 @@ class YandexTranslator(object):
     class that wraps functions, which use the yandex translator under the hood to translate word(s)
     """
 
-    def __init__(self, api_key=None):
+    def __init__(self, api_key=None, source="en", target="de", **kwargs):
         """
         @param api_key: your yandex api key
         """
         if not api_key:
             raise ServerException(401)
         self.__base_url = BASE_URLS.get("YANDEX")
+        self.source = source
+        self.target = target
 
         self.api_key = api_key
         self.api_version = "v1.5"
@@ -79,11 +80,11 @@ class YandexTranslator(object):
             raise ServerException(501)
         return language
 
-    def translate(self, source, target, text, proxies=None):
+    def translate(self, text, proxies=None, **kwargs):
         params = {
             "text": text,
             "format": "plain",
-            "lang": target if source == "auto" else "{}-{}".format(source, target),
+            "lang": self.target if self.source == "auto" else "{}-{}".format(self.source, self.target),
             "key": self.api_key
         }
         try:
@@ -105,11 +106,9 @@ class YandexTranslator(object):
 
         return response['text']
 
-    def translate_file(self, source, target, path):
+    def translate_file(self, path, **kwargs):
         """
         translate from a file
-        @param source: source language
-        @param target: target language
         @param path: path to file
         @return: translated text
         """
@@ -117,16 +116,14 @@ class YandexTranslator(object):
             with open(path) as f:
                 text = f.read()
 
-            return self.translate(source, target, text)
+            return self.translate(text)
         except Exception as e:
             raise e
 
-    def translate_batch(self, source, target, batch):
+    def translate_batch(self, batch, **kwargs):
         """
         translate a batch of texts
-        @param source: source language
-        @param target: target language
         @param batch: list of texts to translate
         @return: list of translations
         """
-        return [self.translate(source, target, text) for text in batch]
+        return [self.translate(text, **kwargs) for text in batch]
